CompGCNLayer
============

.. currentmodule:: pykeen.nn.representation

.. autoclass:: CompGCNLayer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CompGCNLayer.forward
      ~CompGCNLayer.message
      ~CompGCNLayer.reset_parameters

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: message
   .. automethod:: reset_parameters
